@@ -1,9 +1,9 @@
 package Acme::PERLANCAR::Dummy::POD::OverBack;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-14'; # DATE
+our $DATE = '2021-07-09'; # DATE
 our $DIST = 'Acme-PERLANCAR-Dummy-POD'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Testing =over + =back
@@ -20,7 +20,7 @@ Acme::PERLANCAR::Dummy::POD::OverBack - Testing =over + =back
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::PERLANCAR::Dummy::POD::OverBack (from Perl distribution Acme-PERLANCAR-Dummy-POD), released on 2021-04-14.
+This document describes version 0.003 of Acme::PERLANCAR::Dummy::POD::OverBack (from Perl distribution Acme-PERLANCAR-Dummy-POD), released on 2021-07-09.
 
 =head1 DESCRIPTION
 
@@ -44,7 +44,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Acme-PERLANCAR-Dummy-POD/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-PERLANCAR-Dummy-POD>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
